@@ -1,7 +1,4 @@
 package PPIx::EditorTools;
-BEGIN {
-  $PPIx::EditorTools::VERSION = '0.12';
-}
 
 # ABSTRACT: Utility methods and base class for manipulating Perl via PPI
 
@@ -17,6 +14,30 @@ use Class::XSAccessor 1.02 constructor => 'new', accessors => {
 use PPI 1.203;
 use PPIx::EditorTools::ReturnObject;
 
+our $VERSION = '0.14';
+
+=pod
+
+=head1 SYNOPSIS
+
+    See PPIx::EditorTools::*
+
+=head1 DESCRIPTION
+
+Base class and utility methods for manipulating Perl via PPI. Pulled out from
+the C<Padre::Task::PPI> code.
+
+=head1 METHODS
+
+=over 4
+
+=item new()
+
+Constructor. Generally shouldn't be called with any arguments.
+
+=back
+
+=cut
 
 # Used by all the PPIx::EditorTools::* modules
 # Checks for either PPI::Document or take the code as a string and
@@ -323,72 +344,16 @@ sub find_variable_declaration {
 
 1;
 
-
+__END__
 
 =pod
 
-=head1 NAME
-
-PPIx::EditorTools - Utility methods and base class for manipulating Perl via PPI
-
-=head1 VERSION
-
-version 0.12
-
-=head1 SYNOPSIS
-
-    See PPIx::EditorTools::*
-
-=head1 DESCRIPTION
-
-Base class and utility methods for manipulating Perl via PPI. Pulled out from
-the C<Padre::Task::PPI> code.
-
-=head1 METHODS
-
-=over 4
-
-=item new()
-
-Constructor. Generally shouldn't be called with any arguments.
-
-=back
-
 =head1 SEE ALSO
 
 C<PPIx::EditorTools::*>, L<Padre>, L<App::EditorTools>, L<Padre>, and L<PPI>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Steffen Mueller C<smueller@cpan.org>
-
-=item *
-
-Repackaged by Mark Grimes C<mgrimes@cpan.org>
-
-=item *
-
-Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by The Padre development team as listed in Padre.pm.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
-
-__END__
-
-
 # Copyright 2008-2009 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
